package com.lightinit.hsdataplatform.service.admin;

import com.lightinit.hsdataplatform.entity.AtlasRelationship;
import com.lightinit.hsdataplatform.model.ResultState;
import com.lightinit.hsdataplatform.model.admin.*;

import java.sql.ResultSet;
import java.util.List;

public interface IRelationshipManageService {

    List<RelationshipManageListModel> queryRelationshipManageList(RelationshipManageSearchModel inputModel);

    long queryRelationshipManageCount(RelationshipManageSearchModel inputModel);

    List<RelationshipManageListModel> callerList(Long id);

    List<RelationshipManageListModel> calleeList(RelationshipManageSearchModel inputModel);

    long calleeCount(RelationshipManageSearchModel inputModel);

    ResultState doEdit(AtlasRelationshipModel inputModel);

    RelationshipManageViewModel detal(long id, String resourceType);


    List<ResourceAPIRegisterAddAPIInterfaceInputModel> queryInterfaceIn(Long interfaceId);

    List<ResourceAPIRegisterAddAPIInterfaceOutputModel> queryInterfaceOut(Long interfaceId);

    List<RelationshipManageListModel> caller(Long id);

    List<RelationshipManageListModel> callee(Long id);
}
